@@ -3,7 +3,7 @@
 # For license information, see LICENSE.TXT
 """Config"""
 from dataclasses import MISSING, dataclass, field
-from typing import List, Optional, Tuple
+from typing import List, Optional
 import os
 from omegaconf import OmegaConf
 
@@ -61,10 +61,10 @@ class DataConfig:
 
         encode_date_columns (bool): Whether or not to encode the derived variables from date
 
-        validation_split (Union[float, NoneType]): Percentage of Training rows to keep aside as validation.
+        validation_split (Optional[float, NoneType]): Percentage of Training rows to keep aside as validation.
             Used only if Validation Data is not given separately
 
-        continuous_feature_transform (Union[str, NoneType]): Whether or not to transform the features before modelling.
+        continuous_feature_transform (Optional[str, NoneType]): Whether or not to transform the features before modelling.
             By default it is turned off.Choices are: None "yeo-johnson" "box-cox" "quantile_normal" "quantile_uniform"
 
         normalize_continuous_features (bool): Flag to normalize the input features(continuous)
@@ -74,14 +74,14 @@ class DataConfig:
             Please note that this transformation does NOT apply gaussian noise to the resulting data,
             the noise is only applied for QuantileTransformer
 
-        num_workers (Union[int, NoneType]): The number of workers used for data loading. For Windows always set to 0
+        num_workers (Optional[int, NoneType]): The number of workers used for data loading. For Windows always set to 0
     """
 
     target: List[str] = field(
         default=MISSING,
         metadata={"help": "A list of strings with the names of the target column(s)"},
     )
-    continuous_cols: List[str] = field(
+    continuous_cols: List = field(
         default_factory=list,
         metadata={"help": "Column names of the numeric fields. Defaults to []"},
     )
@@ -168,9 +168,11 @@ class TrainerConfig:
 
         max_epochs (int): Maximum number of epochs to be run
 
-        min_epochs (int): Minimum number of epochs to be run
+        min_epochs (int): Force training for at least these many epochs. 1 by default
 
-        gpus (int): The index of the GPU to be used. If `None`, will use CPU
+        max_time (Optional[int]): Stop training after this amount of time has passed. Disabled by default (None)
+
+        gpus (int): Number of gpus to train on (int) or which GPUs to train on (list or str). -1 uses all available GPUs. By default uses CPU (None)
 
         accumulate_grad_batches (int): Accumulates grads every k batches or as set up in the dict.
             Trainer also calls optimizer.step() for the last indivisible step number.
@@ -178,15 +180,21 @@ class TrainerConfig:
         auto_lr_find (bool): Runs a learning rate finder algorithm (see this paper) when calling trainer.tune(),
             to find optimal initial learning rate.
 
+        auto_select_gpus (bool): If enabled and `gpus` is an integer, pick available gpus automatically.
+            This is especially useful when GPUs are configured to be in 'exclusive mode', such that only one 
+            process at a time can access them.
+
         check_val_every_n_epoch (int): Check val every n train epochs.
 
+        deterministic (bool): If true enables cudnn.deterministic. Might make your system slower, but ensures reproducibility.
+
         gradient_clip_val (float): Gradient clipping value
 
         overfit_batches (float): Uses this much data of the training set. If nonzero, will use the same training set
             for validation and testing. If the training dataloaders have shuffle=True, Lightning will automatically disable it.
             Useful for quickly debugging or trying to overfit on purpose.
 
-        profiler (Union[str, NoneType]): To profile individual steps during training and assist in identifying bottlenecks.
+        profiler (Optional[str, NoneType]): To profile individual steps during training and assist in identifying bottlenecks.
             Choices are: 'None' 'simple' 'advanced'
 
         early_stopping (str): The loss/metric that needed to be monitored for early stopping. If None, there will be no early stopping
@@ -219,17 +227,20 @@ class TrainerConfig:
         default=64, metadata={"help": "Number of samples in each batch of training"}
     )
     fast_dev_run: bool = field(
-        default=False, metadata={"help": "Quick Debug Run of Val"}
+        default=False, metadata={"help": "runs n if set to ``n`` (int) else 1 if set to ``True`` batch(es) of train, val and test to find any bugs (ie: a sort of unit test)."}
     )
     max_epochs: int = field(
         default=10, metadata={"help": "Maximum number of epochs to be run"}
     )
-    min_epochs: int = field(
-        default=1, metadata={"help": "Minimum number of epochs to be run"}
+    min_epochs: Optional[int] = field(
+        default=1, metadata={"help": "Force training for at least these many epochs. 1 by default"}
+    )
+    max_time: Optional[int] = field(
+        default=None, metadata={"help": "Stop training after this amount of time has passed. Disabled by default (None)"}
     )
     gpus: Optional[int] = field(
         default=None,
-        metadata={"help": "The index of the GPU to be used. If None, will use CPU"},
+        metadata={"help": "Number of gpus to train on (int). -1 uses all available GPUs. By default uses CPU (None)"},
     )
     accumulate_grad_batches: int = field(
         default=1,
@@ -243,6 +254,12 @@ class TrainerConfig:
             "help": "Runs a learning rate finder algorithm (see this paper) when calling trainer.tune(), to find optimal initial learning rate."
         },
     )
+    auto_select_gpus: bool = field(
+        default=True,
+        metadata={
+            "help": "If enabled and `gpus` is an integer, pick available gpus automatically. This is especially useful when GPUs are configured to be in 'exclusive mode', such that only one process at a time can access them."
+        },
+    )
     check_val_every_n_epoch: int = field(
         default=1, metadata={"help": "Check val every n train epochs."}
     )
@@ -255,6 +272,12 @@ class TrainerConfig:
             "help": "Uses this much data of the training set. If nonzero, will use the same training set for validation and testing. If the training dataloaders have shuffle=True, Lightning will automatically disable it. Useful for quickly debugging or trying to overfit on purpose."
         },
     )
+    deterministic: bool = field(
+        default=False,
+        metadata={
+            "help": "If true enables cudnn.deterministic. Might make your system slower, but ensures reproducibility."
+        },
+    )
     profiler: Optional[str] = field(
         default=None,
         metadata={
@@ -334,10 +357,10 @@ class ExperimentConfig:
                 For Tensorboard this defines the folder under which the logs will be saved and
                 for W&B it defines the project name.
 
-            run_name (Union[str, NoneType]): The name of the run; a specific identifier to
+            run_name (Optional[str, NoneType]): The name of the run; a specific identifier to
                 recognize the run. If left blank, will be assigned a auto-generated name
 
-            exp_watch (Union[str, NoneType]): The level of logging required.
+            exp_watch (Optional[str, NoneType]): The level of logging required.
                 Can be `gradients`, `parameters`, `all` or `None`. Defaults to None
 
             log_target (str): Determines where logging happens - Tensorboard or W&BChoices are: wandb tensorboard
@@ -407,12 +430,12 @@ class OptimizerConfig:
 
         optimizer_params (dict): The parameters for the optimizer. If left blank, will use default parameters.
 
-        lr_scheduler (Union[str, NoneType]): The name of the LearningRateScheduler to use, if any, from [torch.optim.lr_scheduler](https://pytorch.org/docs/stable/optim.html#how-to-adjust-learning-rate). 
+        lr_scheduler (Optional[str, NoneType]): The name of the LearningRateScheduler to use, if any, from [torch.optim.lr_scheduler](https://pytorch.org/docs/stable/optim.html#how-to-adjust-learning-rate). 
             If None, will not use any scheduler. Defaults to `None`
 
-        lr_scheduler_params (Union[dict, NoneType]): The parameters for the LearningRateScheduler. If left blank, will use default parameters.
+        lr_scheduler_params (Optional[dict, NoneType]): The parameters for the LearningRateScheduler. If left blank, will use default parameters.
 
-        lr_scheduler_monitor_metric (Union[str, NoneType]): Used with `ReduceLROnPlateau`, where the plateau is decided based on this metric
+        lr_scheduler_monitor_metric (Optional[str, NoneType]): Used with `ReduceLROnPlateau`, where the plateau is decided based on this metric
     """
 
     optimizer: str = field(
@@ -456,14 +479,14 @@ class OptimizerConfig:
 class ExperimentRunManager:
     def __init__(
         self,
-        exp_version_manager: str = ".tmp/exp_version_manager.yml",
+        exp_version_manager: str = ".pt_tmp/exp_version_manager.yml",
     ) -> None:
         """The manages the versions of the experiments based on the name. It is a simple dictionary(yaml) based lookup.
         Primary purpose is to avoid overwriting of saved models while runing the training without changing the experiment name.
 
         Args:
             exp_version_manager (str, optional): The path of the yml file which acts as version control.
-            Defaults to ".tmp/exp_version_manager.yml".
+            Defaults to ".pt_tmp/exp_version_manager.yml".
         """
         super().__init__()
         self._exp_version_manager = exp_version_manager
@@ -471,7 +494,7 @@ class ExperimentRunManager:
             self.exp_version_manager = OmegaConf.load(exp_version_manager)
         else:
             self.exp_version_manager = OmegaConf.create({})
-            os.makedirs(".tmp", exist_ok=True)
+            os.makedirs(os.path.split(exp_version_manager)[0], exist_ok=True)
             with open(self._exp_version_manager, "w") as file:
                 OmegaConf.save(config=self.exp_version_manager, f=file)
 
@@ -492,19 +515,23 @@ class ModelConfig:
     Args:
         task (str): Specify whether the problem is regression of classification.Choices are: regression classification
 
+        embedding_dims (Optional[List[int], NoneType]): The dimensions of the embedding for each categorical column
+            as a list of tuples (cardinality, embedding_dim). If left empty, will infer using the cardinality of the categorical column
+            using the rule min(50, (x + 1) // 2). Will only be used if the model uses categorical embedding.
+
         learning_rate (float): The learning rate of the model
 
-        loss (Union[str, NoneType]): The loss function to be applied.
+        loss (Optional[str, NoneType]): The loss function to be applied.
             By Default it is MSELoss for regression and CrossEntropyLoss for classification.
             Unless you are sure what you are doing, leave it at MSELoss or L1Loss for regression and CrossEntropyLoss for classification
 
-        metrics (Union[List[str], NoneType]): the list of metrics you need to track during training.
+        metrics (Optional[List[str], NoneType]): the list of metrics you need to track during training.
             The metrics should be one of the metrics implemented in PyTorch Lightning.
             By default, it is accuracy if classification and mean_squared_error for regression
 
-        metrics_params (Union[List, NoneType]): The parameters to be passed to the metrics function
+        metrics_params (Optional[List, NoneType]): The parameters to be passed to the metrics function
 
-        target_range (Union[List, NoneType]): The range in which we should limit the output variable. Currently ignored for multi-target regression
+        target_range (Optional[List, NoneType]): The range in which we should limit the output variable. Currently ignored for multi-target regression
             Typically used for Regression problems. If left empty, will not apply any restrictions
 
     Raises:
@@ -518,6 +545,12 @@ class ModelConfig:
             "choices": ["regression", "classification"],
         }
     )
+    embedding_dims: Optional[List[int]] = field(
+        default=None,
+        metadata={
+            "help": "The dimensions of the embedding for each categorical column as a list of tuples (cardinality, embedding_dim). If left empty, will infer using the cardinality of the categorical column using the rule min(50, (x + 1) // 2)"
+        },
+    )
     learning_rate: float = field(
         default=1e-3, metadata={"help": "The learning rate of the model"}
     )
@@ -530,7 +563,7 @@ class ModelConfig:
     metrics: Optional[List[str]] = field(
         default=None,
         metadata={
-            "help": "the list of metrics you need to track during training. The metrics should be one of the functional metrics implemented in PyTorch Lightning. By default, it is accuracy if classification and MeanSquaredLogError for regression"
+            "help": "the list of metrics you need to track during training. The metrics should be one of the functional metrics implemented in ``torchmetrics``. By default, it is accuracy if classification and mean_squared_error for regression"
         },
     )
     metrics_params: Optional[List] = field(
@@ -543,6 +576,12 @@ class ModelConfig:
             "help": "The range in which we should limit the output variable. Currently ignored for multi-target regression. Typically used for Regression problems. If left empty, will not apply any restrictions"
         },
     )
+    seed: int = field(
+        default=42,
+        metadata={
+            "help": "The seed for reproducibility. Defaults to 42"
+        },
+    )
 
     def __post_init__(self):
         if self.task == "regression":
