@@ -12,6 +12,8 @@ from .mixture_density import (
     AutoIntMDNConfig
 )
 from .autoint import AutoIntConfig, AutoIntModel
+from .tab_transformer import TabTransformerConfig, TabTransformerModel
+from .ft_transformer import FTTransformerConfig, FTTransformerModel
 from .base_model import BaseModel
 from . import category_embedding, node, mixture_density, tabnet, autoint
 
@@ -33,9 +35,14 @@ __all__ = [
     "AutoIntMDNConfig",
     "AutoIntConfig",
     "AutoIntModel",
+    "TabTransformerConfig", 
+    "TabTransformerModel",
+    "FTTransformerConfig", 
+    "FTTransformerModel",
     "category_embedding",
     "node",
     "mixture_density",
     "tabnet",
     "autoint",
+    "tab_transformer"
 ]
\ No newline at end of file
