@@ -8,6 +8,7 @@ from typing import Callable, Dict, List, Optional
 
 import pytorch_lightning as pl
 import torch
+import torchmetrics
 import torch.nn as nn
 from omegaconf import DictConfig
 
@@ -73,13 +74,13 @@ class BaseModel(pl.LightningModule, metaclass=ABCMeta):
     def _setup_metrics(self):
         if self.custom_metrics is None:
             self.metrics = []
-            task_module = pl.metrics.functional
+            task_module = torchmetrics.functional
             for metric in self.hparams.metrics:
                 try:
                     self.metrics.append(getattr(task_module, metric))
                 except AttributeError as e:
                     logger.error(
-                        f"{metric} is not a valid functional metric defined in the pytorch_lightning.metrics.functional module"
+                        f"{metric} is not a valid functional metric defined in the torchmetrics.functional module"
                     )
                     raise e
         else:
@@ -102,6 +103,7 @@ class BaseModel(pl.LightningModule, metaclass=ABCMeta):
                 )
             computed_loss = torch.stack(losses, dim=0).sum()
         else:
+            #TODO loss fails with batch size of 1
             computed_loss = self.loss(y_hat.squeeze(), y.squeeze())
         self.log(
             f"{tag}_loss",
@@ -119,12 +121,12 @@ class BaseModel(pl.LightningModule, metaclass=ABCMeta):
         for metric, metric_str, metric_params in zip(
             self.metrics, self.hparams.metrics, self.hparams.metrics_params
         ):
-            if (self.hparams.task == "regression") and (self.hparams.output_dim > 1):
+            if (self.hparams.task == "regression"):
                 _metrics = []
                 for i in range(self.hparams.output_dim):
                     if (
                         metric.__name__
-                        == pl.metrics.functional.mean_squared_log_error.__name__
+                        == torchmetrics.functional.mean_squared_log_error.__name__
                     ):
                         # MSLE should only be used in strictly positive targets. It is undefined otherwise
                         _metric = metric(
@@ -145,7 +147,8 @@ class BaseModel(pl.LightningModule, metaclass=ABCMeta):
                     _metrics.append(_metric)
                 avg_metric = torch.stack(_metrics, dim=0).sum()
             else:
-                avg_metric = metric(y_hat.squeeze(), y.squeeze(), **metric_params)
+                y_hat = nn.Softmax(dim=-1)(y_hat.squeeze())
+                avg_metric = metric(y_hat, y.squeeze(), **metric_params)
             metrics.append(avg_metric)
             self.log(
                 f"{tag}_{metric_str}",
@@ -156,6 +159,9 @@ class BaseModel(pl.LightningModule, metaclass=ABCMeta):
                 prog_bar=True,
             )
         return metrics
+    
+    def data_aware_initialization(self, datamodule):
+        pass
 
     @abstractmethod
     def forward(self, x: Dict):
@@ -265,7 +271,8 @@ class BaseModel(pl.LightningModule, metaclass=ABCMeta):
 
     def validation_epoch_end(self, outputs) -> None:
         do_log_logits = (
-            self.hparams.log_logits
+            hasattr(self.hparams, "log_logits")
+            and self.hparams.log_logits
             and self.hparams.log_target == "wandb"
             and WANDB_INSTALLED
         )
