@@ -108,7 +108,7 @@ class TabularDatamodule(pl.LightningDataModule):
                 int(self.train[col].fillna("NA").nunique()) + 1
                 for col in self.config.categorical_cols
             ]
-            if self.config.embedding_dims is None:
+            if hasattr(self.config, "embedding_dims") and self.config.embedding_dims is None:
                 self.config.embedding_dims = [
                     (x, min(50, (x + 1) // 2))
                     for x in self.config.categorical_cardinality
@@ -232,14 +232,20 @@ class TabularDatamodule(pl.LightningDataModule):
         # Target Transforms
         if all([col in data.columns for col in self.config.target]):
             if self.do_target_transform:
-                target_transforms = []
-                for col in self.config.target:
-                    _target_transform = copy.deepcopy(self.target_transform_template)
-                    data[col] = _target_transform.fit_transform(
-                        data[col].values.reshape(-1, 1)
-                    )
-                    target_transforms.append(_target_transform)
-                self.target_transforms = target_transforms
+                if stage == "fit":
+                    target_transforms = []
+                    for col in self.config.target:
+                        _target_transform = copy.deepcopy(self.target_transform_template)
+                        data[col] = _target_transform.fit_transform(
+                            data[col].values.reshape(-1, 1)
+                        )
+                        target_transforms.append(_target_transform)
+                    self.target_transforms = target_transforms
+                else:
+                    for col, _target_transform in zip(self.config.target, self.target_transforms):
+                        data[col] = _target_transform.transform(
+                            data[col].values.reshape(-1, 1)
+                        )
         return data, added_features
 
     def setup(self, stage: Optional[str] = None) -> None:
@@ -433,7 +439,7 @@ class TabularDatamodule(pl.LightningDataModule):
             )
             df.insert(3, prefix + "Week", week)
             added_features.append(prefix + "Week")
-        # Not adding Elapsed by default. Need to route it through config
+        #TODO Not adding Elapsed by default. Need to route it through config
         # mask = ~field.isna()
         # df[prefix + "Elapsed"] = np.where(
         #     mask, field.values.astype(np.int64) // 10 ** 9, None
@@ -443,10 +449,10 @@ class TabularDatamodule(pl.LightningDataModule):
             df.drop(field_name, axis=1, inplace=True)
 
         # Removing features woth zero variations
-        for col in added_features:
-            if len(df[col].unique()) == 1:
-                df.drop(columns=col, inplace=True)
-                added_features.remove(col)
+        # for col in added_features:
+        #     if len(df[col].unique()) == 1:
+        #         df.drop(columns=col, inplace=True)
+        #         added_features.remove(col)
         return df, added_features
 
     def train_dataloader(self, batch_size: Optional[int] = None) -> DataLoader:
