@@ -3,11 +3,13 @@
 # For license information, see LICENSE.TXT
 """Tabular Model"""
 from collections import defaultdict
+from pytorch_lightning.utilities.seed import seed_everything
 import logging
 import os
 from typing import Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 import joblib
+import inspect
 import numpy as np
 import pandas as pd
 import pytorch_lightning as pl
@@ -18,6 +20,7 @@ from pytorch_lightning.utilities.cloud_io import load as pl_load
 from sklearn.base import TransformerMixin
 from torch import nn
 from tqdm.autonotebook import tqdm
+from pytorch_tabular import config
 
 import pytorch_tabular.models as models
 from pytorch_tabular.config import (
@@ -78,16 +81,6 @@ class TabularModel:
             ), "If `config` is None, `data_config`, `model_config`, `trainer_config`, and `optimizer_config` cannot be None"
             data_config = self._read_parse_config(data_config, DataConfig)
             model_config = self._read_parse_config(model_config, ModelConfig)
-            # # Re-routing to Categorical embedding Model if embed_categorical is true for NODE
-            # if (
-            #     hasattr(model_config, "_model_name")
-            #     and (model_config._model_name == "NODEModel")
-            #     and (model_config.embed_categorical)
-            #     and ("CategoryEmbedding" not in model_config._model_name)
-            # ):
-            #     model_config._model_name = (
-            #         "CategoryEmbedding" + model_config._model_name
-            #     )
             trainer_config = self._read_parse_config(trainer_config, TrainerConfig)
             optimizer_config = self._read_parse_config(
                 optimizer_config, OptimizerConfig
@@ -115,8 +108,8 @@ class TabularModel:
                 )
         else:
             self.config = config
-            if not hasattr(config, "log_target") and (config.log_target is not None):
-                experiment_config = OmegaConf.structured(experiment_config)
+            if hasattr(config, "log_target") and (config.log_target is not None):
+                # experiment_config = OmegaConf.structured(experiment_config)
                 self.track_experiment = True
             else:
                 logger.info("Experiment Tracking is turned off")
@@ -191,9 +184,12 @@ class TabularModel:
         Returns:
             tuple[str, int]: Returns the name and version number
         """
-        if self.config.run_name is not None:
+        if hasattr(self.config, "run_name") and self.config.run_name is not None:
             name = self.config.run_name
-        elif self.config.checkpoints_name is not None:
+        elif (
+            hasattr(self.config, "checkpoints_name")
+            and self.config.checkpoints_name is not None
+        ):
             name = self.config.checkpoints_name
         else:
             name = self.config.task
@@ -254,23 +250,6 @@ class TabularModel:
         logger.debug(f"Callbacks used: {callbacks}")
         return callbacks
 
-    def data_aware_initialization(self):
-        """Performs data-aware initialization for NODE"""
-        logger.info("Data Aware Initialization....")
-        # Need a big batch to initialize properly
-        alt_loader = self.datamodule.train_dataloader(batch_size=2000)
-        batch = next(iter(alt_loader))
-        for k, v in batch.items():
-            if isinstance(v, list) and (len(v) == 0):
-                # Skipping empty list
-                continue
-            # batch[k] = v.to("cpu" if self.config.gpu == 0 else "cuda")
-            batch[k] = v.to(self.model.device)
-
-        # single forward pass to initialize the ODST
-        with torch.no_grad():
-            self.model(batch)
-
     def _prepare_dataloader(
         self, train, validation, test, target_transform=None, train_sampler=None
     ):
@@ -311,9 +290,8 @@ class TabularModel:
                 custom_optimizer=optimizer,
                 custom_optimizer_params=optimizer_params,
             )
-            # Data Aware Initialization (NODE)
-            if self.config._model_name in ["NODEModel"]:
-                self.data_aware_initialization()
+            # Data Aware Initialization(for the models that need it)
+            self.model.data_aware_initialization(self.datamodule)
 
     def _prepare_trainer(self, max_epochs=None, min_epochs=None):
         logger.info("Preparing the Trainer...")
@@ -322,7 +300,8 @@ class TabularModel:
         if min_epochs is not None:
             self.config.min_epochs = min_epochs
         # TODO get Trainer Arguments from the init signature
-        trainer_args = vars(pl.Trainer()).keys()
+        trainer_sig = inspect.signature(pl.Trainer.__init__)
+        trainer_args = [p for p in trainer_sig.parameters.keys() if p != "self"]
         trainer_args_config = {
             k: v for k, v in self.config.items() if k in trainer_args
         }
@@ -339,9 +318,14 @@ class TabularModel:
         if self.trainer.checkpoint_callback is not None:
             logger.info("Loading the best model...")
             ckpt_path = self.trainer.checkpoint_callback.best_model_path
-            logger.debug(f"Model Checkpoint: {ckpt_path}")
-            ckpt = pl_load(ckpt_path, map_location=lambda storage, loc: storage)
-            self.model.load_state_dict(ckpt["state_dict"])
+            if ckpt_path != "":
+                logger.debug(f"Model Checkpoint: {ckpt_path}")
+                ckpt = pl_load(ckpt_path, map_location=lambda storage, loc: storage)
+                self.model.load_state_dict(ckpt["state_dict"])
+            else:
+                logger.info(
+                    "No best model available to load. Did you run it more than 1 epoch?..."
+                )
         else:
             logger.info(
                 "No best model available to load. Did you run it more than 1 epoch?..."
@@ -360,7 +344,7 @@ class TabularModel:
         target_transform: Optional[Union[TransformerMixin, Tuple]],
         max_epochs: int,
         min_epochs: int,
-        reset: bool,
+        reset: bool
     ):
         """Prepares the dataloaders, trainer, and model for the fit process"""
         if target_transform is not None:
@@ -406,6 +390,7 @@ class TabularModel:
         max_epochs: Optional[int] = None,
         min_epochs: Optional[int] = None,
         reset: bool = False,
+        seed: Optional[int] = None,
     ) -> None:
         """The fit method which takes in the data and triggers the training
 
@@ -439,7 +424,10 @@ class TabularModel:
             min_epochs (Optional[int]): Overwrite minimum number of epochs to be run
 
             reset: (bool): Flag to reset the model and train again from scratch
+
+            seed: (int): If you have to override the default seed set as part of of ModelConfig
         """
+        seed_everything(seed if seed is not None else self.config.seed)
         train_loader, val_loader = self._pre_fit(
             train,
             validation,
@@ -457,9 +445,8 @@ class TabularModel:
         self.model.train()
         if self.config.auto_lr_find and (not self.config.fast_dev_run):
             self.trainer.tune(self.model, train_loader, val_loader)
-            # Parameters in NODE needs to be initialized again
-            if self.config._model_name in ["CategoryEmbeddingNODEModel", "NODEModel"]:
-                self.data_aware_initialization()
+            # Parameters in models needs to be initialized again after LR find
+            self.model.data_aware_initialization(self.datamodule)
         self.model.train()
         self.trainer.fit(self.model, train_loader, val_loader)
         logger.info("Training the model completed...")
@@ -729,11 +716,16 @@ class TabularModel:
             )
 
     @classmethod
-    def load_from_checkpoint(cls, dir: str):
+    def load_from_checkpoint(cls, dir: str, map_location = None, strict=True):
         """Loads a saved model from the directory
 
         Args:
             dir (str): The directory where the model wa saved, along with the checkpoints
+            map_location (Union[Dict[str, str], str, device, int, Callable, None]) – If your checkpoint 
+                saved a GPU model and you now load on CPUs or a different number of GPUs, use this to map 
+                to the new setup. The behaviour is the same as in torch.load()
+            strict (bool) – Whether to strictly enforce that the keys in checkpoint_path match the keys 
+                returned by this module’s state dict. Default: True.
 
         Returns:
             TabularModel: The saved TabularModel
@@ -763,19 +755,18 @@ class TabularModel:
         custom_params = joblib.load(os.path.join(dir, "custom_params.sav"))
         model_args = {}
         if custom_params.get("custom_loss") is not None:
-            model_args['loss'] = "MSELoss"
+            model_args["loss"] = "MSELoss"
         if custom_params.get("custom_metrics") is not None:
-            model_args['metrics'] = ["mean_squared_error"]
-            model_args['metric_params'] = [{}]
+            model_args["metrics"] = ["mean_squared_error"]
+            model_args["metric_params"] = [{}]
         if custom_params.get("custom_optimizer") is not None:
-            model_args['optimizer'] = "Adam"
+            model_args["optimizer"] = "Adam"
         if custom_params.get("custom_optimizer_params") is not None:
-            model_args['optimizer_params'] = {}
-        
+            model_args["optimizer_params"] = {}
+
         # Initializing with default metrics, losses, and optimizers. Will revert once initialized
         model = model_callable.load_from_checkpoint(
-            checkpoint_path=os.path.join(dir, "model.ckpt"),
-            **model_args
+            checkpoint_path=os.path.join(dir, "model.ckpt"),map_location=map_location, strict=strict, **model_args
         )
         # else:
         #     # Initializing with default values
